@@ -1,6 +1,5 @@
-from typing import Optional, List
-
 from dataclasses import dataclass
+from typing import Optional, List, Any, Dict
 
 from nuclear.args.container import ArgsContainer
 from nuclear.builder.rule import SubcommandRule, CliRule
@@ -13,3 +12,4 @@ class RunContext(object):
     action: Optional[Action]
     active_subcommands: List[SubcommandRule]
     active_rules: List[CliRule]
+    internal_vars: Dict[str, Any]
