@@ -1,5 +1,4 @@
 import os
-import sys
 import traceback
 from contextlib import contextmanager
 from typing import Dict, Any, Collection, Iterable
@@ -10,7 +9,11 @@ from .wrap_error import ContextError
 
 @contextmanager
 def logerr(context_name: str = '', print_traceback: bool = True):
-    """Catches all exceptions and displays traceback in pretty, concise format"""
+    """
+    Catch all exceptions and display traceback in pretty, concise format
+    :param context_name: description of the operation to show in case of error
+    :param print_traceback: whether to print traceback or not in case of error
+    """
     try:
         yield
     except KeyboardInterrupt:
@@ -36,6 +39,13 @@ def _print_error_context(e: Exception, ctx: Dict[str, Any], print_traceback: boo
     log.error(error_msg, **ctx)
 
 
+def log_exception(e: BaseException, print_traceback: bool = True):
+    """
+    Log exception in concise one-line format containing message, exception type and short traceback
+    """
+    _print_error_context(e, {}, print_traceback, '')
+
+
 def _root_cause_type(e: Exception) -> str:
     while e.__cause__ is not None:
         e = e.__cause__
